@@ -253,9 +253,9 @@ bool Edid::Private::parse(const QByteArray &rawData)
      * |\---/\---/\---/
      * R  C1   C2   C3 */
     pnpId.resize(3);
-    pnpId[0] = 'A' + ((data[GCM_EDID_OFFSET_PNPID + 0] & 0x7c) / 4) - 1;
-    pnpId[1] = 'A' + ((data[GCM_EDID_OFFSET_PNPID + 0] & 0x3) * 8) + ((data[GCM_EDID_OFFSET_PNPID + 1] & 0xe0) / 32) - 1;
-    pnpId[2] = 'A' + (data[GCM_EDID_OFFSET_PNPID + 1] & 0x1f) - 1;
+    pnpId[0] = QLatin1Char('A' + ((data[GCM_EDID_OFFSET_PNPID + 0] & 0x7c) / 4) - 1);
+    pnpId[1] = QLatin1Char('A' + ((data[GCM_EDID_OFFSET_PNPID + 0] & 0x3) * 8) + ((data[GCM_EDID_OFFSET_PNPID + 1] & 0xe0) / 32) - 1);
+    pnpId[2] = QLatin1Char('A' + (data[GCM_EDID_OFFSET_PNPID + 1] & 0x1f) - 1);
 
     // load the PNP_IDS file and load the vendor name
     QFile pnpIds(QStringLiteral(PNP_IDS));
@@ -401,3 +401,5 @@ QString Edid::Private::edidParseString(const quint8 *data) const
     }
     return text;
 }
+
+#include "moc_edid.cpp"
